Learn R Programming

apexcharter (version 0.2.0)

ax_dataLabels: Labels on data

Description

Labels on data

Usage

ax_dataLabels(
  ax,
  enabled = NULL,
  textAnchor = NULL,
  offsetX = NULL,
  offsetY = NULL,
  style = NULL,
  dropShadow = NULL,
  formatter = NULL,
  ...
)

Arguments

ax

A apexcharts htmlwidget object.

enabled

To determine whether to show dataLabels or not.

textAnchor

The alignment of text relative to dataLabel's drawing position. Accepted values "start", "middle" or "end".

offsetX

Sets the left offset for dataLabels.

offsetY

Sets the top offset for dataLabels.

style

A list of parameters.

dropShadow

A list of parameters.

formatter

The formatter function takes in a single value and allows you to format the value before displaying

...

Additional parameters.

Value

A apexcharts htmlwidget object.

Examples

Run this code
# NOT RUN {
data("diamonds", package = "ggplot2")

# Add data labels
apex(
  data = diamonds,
  mapping = aes(x = cut)
) %>%
  ax_dataLabels(enabled = TRUE)
# }

Run the code above in your browser using DataLab