powered by
Labels on data
ax_dataLabels( ax, enabled = NULL, textAnchor = NULL, offsetX = NULL, offsetY = NULL, style = NULL, dropShadow = NULL, formatter = NULL, ... )
A apexcharts htmlwidget object.
apexcharts
htmlwidget
To determine whether to show dataLabels or not.
The alignment of text relative to dataLabel's drawing position. Accepted values "start", "middle" or "end".
"start"
"middle"
"end"
Sets the left offset for dataLabels.
Sets the top offset for dataLabels.
A list of parameters.
The formatter function takes in a single value and allows you to format the value before displaying
Additional parameters.
# NOT RUN { data("diamonds", package = "ggplot2") # Add data labels apex( data = diamonds, mapping = aes(x = cut) ) %>% ax_dataLabels(enabled = TRUE) # }
Run the code above in your browser using DataLab