powered by
Fix tooltip
set_tooltip_fixed( ax, position = c("topLeft", "topRight", "bottomLeft", "bottomRight"), offsetX = NULL, offsetY = NULL )
An apexcharts htmlwidget object.
apexcharts
htmlwidget
Predefined position: "topLeft", "topRight", "bottomLeft" or "bottomRight".
"topLeft"
"topRight"
"bottomLeft"
"bottomRight"
Sets the left offset for the tooltip container in fixed position.
Sets the top offset for the tooltip container in fixed position.
# NOT RUN { library(apexcharter) data("economics", package = "ggplot2") apex( data = tail(economics, 350), mapping = aes(x = date, y = uempmed), type = "line" ) %>% set_tooltip_fixed() # }
Run the code above in your browser using DataLab